@@ -26,7 +26,8 @@ __all__ = ['Registry', 'SettingRegistry', 'ExporterRegistry',
            'SessionPatchRegistry', 'session_patch',
            'AutoLinkerRegistry', 'autolinker',
            'DataTranslatorRegistry', 'data_translator',
-           'SubsetDefinitionTranslatorRegistry', 'subset_state_translator']
+           'SubsetDefinitionTranslatorRegistry', 'subset_state_translator',
+           'UnitConverterRegistry', 'unit_converter']
 
 
 CFG_DIR = os.path.join(os.path.expanduser('~'), '.glue')
@@ -608,6 +609,25 @@ class SubsetDefinitionTranslatorRegistry(Registry):
             raise ValueError("Invalid subset state handler format '{0}' - should be one of:".format(format) + format_choices(all_formats))
 
 
+class UnitConverterRegistry(DictRegistry):
+    """
+    Stores unit converters, which are classes that can be used to determine
+    conversion between units and find equivalent units to other units.
+    """
+
+    def add(self, label, converter_cls):
+        if label in self.members:
+            raise ValueError("Unit converter class '{0}' already registered".format(label))
+        else:
+            self.members[label] = converter_cls
+
+    def __call__(self, label):
+        def adder(converter_cls):
+            self.add(label, converter_cls)
+            return converter_cls
+        return adder
+
+
 class QtClientRegistry(Registry):
     """
     Stores QT widgets to visualize data.
@@ -978,6 +998,9 @@ subset_mask_importer = SubsetMaskImporterRegistry()
 data_translator = DataTranslatorRegistry()
 subset_state_translator = SubsetDefinitionTranslatorRegistry()
 
+# Units
+unit_converter = UnitConverterRegistry()
+
 # Backward-compatibility
 single_subset_action = layer_action
 
@@ -1067,3 +1090,12 @@ settings.add('SHOW_INFO_PROFILE_OPEN', True, validator=bool)
 settings.add('SHOW_WARN_PROFILE_DUPLICATE', True, validator=bool)
 settings.add('FONT_SIZE', -1.0, validator=float)
 settings.add('AUTOLINK', {}, validator=dict)
+
+
+def check_unit_converter(value):
+    if value != 'default' and value not in unit_converter.members:
+        raise KeyError(f'Unit converter {value} is not defined')
+    return value
+
+
+settings.add('UNIT_CONVERTER', 'default', validator=check_unit_converter)
