@@ -3,7 +3,7 @@ from glue.core import Data
 from glue.core.exceptions import IncompatibleAttribute, IncompatibleDataException
 from glue.core.component import DaskComponent
 from glue.core.coordinate_helpers import dependent_axes
-from glue.utils import unbroadcast, broadcast_to, broadcast_arrays_minimal
+from glue.utils import unbroadcast, broadcast_arrays_minimal
 
 # TODO: cache needs to be updated when links are removed/changed
 
@@ -73,7 +73,7 @@ def translate_pixel(data, pixel_coords, target_cid):
         shape = values_all[0].shape
         values_all = broadcast_arrays_minimal(*values_all)
         results = link._using(*values_all)
-        result = broadcast_to(results, shape)
+        result = np.broadcast_to(results, shape)
     else:
         result = None
     return result, sorted(set(dimensions_all))
@@ -222,7 +222,7 @@ def compute_fixed_resolution_buffer(data, bounds, target_data=None, target_cid=N
         invalid_all |= invalid
 
         # Broadcast back to the original shape and add to the list
-        translated_coords.append(broadcast_to(translated_coord, original_shape))
+        translated_coords.append(np.broadcast_to(translated_coord, original_shape))
 
         # Also keep track of all the dimensions that contributed to this coordinate
         dimensions_all.extend(dimensions)
