@@ -363,8 +363,12 @@ class DataGraphWidget(QGraphicsView):
 
     def find_object(self, event):
         for obj in list(self.nodes) + self.edges:
-            if obj.contains(event.position()):
-                return obj
+            try:  # event.position() is Qt6
+                if obj.contains(event.position()):
+                    return obj
+            except AttributeError:  # event.pos() is Qt5
+                if obj.contains(event.pos()):
+                    return obj
 
     def mouseMoveEvent(self, event):
 
